CryptoError

Enum CryptoError 

#[non_exhaustive]
pub enum CryptoError { DecodingError(DecodeError), InsufficientMemory, NotARecipient(Fingerprint), NotDecrypted, NotSecret, NotType(MessageDesc), SerializationError(Error), UnauthenticCipher, Unknown, }
Error type used for all fallible operations.

It is recommended to use anyhow for easy error handling or error propagation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


DecodingError(DecodeError)

Base64 decoding error. See base64::DecodeError for more details.



InsufficientMemory

Insufficient memory error.



NotARecipient(Fingerprint)

Not a recipient error, see this example.



NotDecrypted

The message is not decrypted, cannot verify the signature.



NotSecret

The certificate does not contain secret keys, but it should.



NotType(MessageDesc)

The message parsing failed because the message is not of expected type.



SerializationError(Error)

Serialization error. See postcard::Error for more details.



UnauthenticCipher

AAD authentication error. This would usually indicate that the message is not authentic.



Unknown

Any other error for which there’s no logical cause to happen.