MessageFinal

Trait MessageFinal 

pub trait MessageFinal {
    type R;

    // Required method
    fn finalize(self) -> Self::R;
}
The trait used to indicate an intermediate type may finalize a message.

More about those intermediate types may be read here. The following hidden types implement this trait:

  • SignedMessage,
  • SymEncryptedMessage,
  • AsmEncryptedMessage.

Required Associated Types

type R

The return type of the finalize method.

Either Message or Result<Message>

Required Methods

fn finalize(self) -> Self::R

Finalaze the message and return R.

Implementors